import os
import yaml


class Namespace(object):

    def __init__(self, **kwargs):
        self.__dict__.update(kwargs)

    def __getitem__(self, item):
        return getattr(self, item)

    def __setitem__(self, key, value):
        setattr(self, key, value)

    def update(self, other):
        self.__dict__.update(other)


def load_yaml(filename, conf_dirs):
    for conf_dir in conf_dirs:
        path = os.path.join(conf_dir, filename)

        if os.path.exists(path):
            with open(path) as f:
                return yaml.safe_load(f)

    raise IOError('%s not found in %r' % (filename, conf_dirs))

BASE_DIR = os.path.dirname(os.path.abspath(__file__))

settings = Namespace(
    DEBUG=False,
    LISTEN_PORT=8888,
    STORAGE_SHARED=os.path.join(BASE_DIR, 'storage', 'shared'),
    STORAGE_UUID=os.path.join(BASE_DIR, 'storage'),
    STORAGE_FILENAME='.status',
    REDIRECT_HEADER='X-Accel-Redirect',
    REDIRECT_SHARED='/proxy_storage_shared/',
    REDIRECT_UUID='/proxy_storage_uuid/',
)
